@@ -30,7 +30,6 @@ from resotolib.baseresources import (
 from resotolib.config import Config, current_config
 from resotolib.core.actions import CoreFeedback
 from resotolib.graph import Graph, EdgeKey, ByNodeId, BySearchCriteria, NodeSelector
-from resotolib.json import to_json as to_js, from_json as from_js
 from resotolib.json_bender import Bender, bend
 from resotolib.lock import RWLock
 from resotolib.proc import set_thread_name
@@ -89,7 +88,8 @@ class AwsResource(BaseResource, ABC):
     def delete_resource_tag(self, client: AwsClient, key: str) -> bool:
         return False
 
-    def delete_resource(self, client: AwsClient) -> bool:
+    def delete_resource(self, client: AwsClient, graph: Graph) -> bool:
+        log.info(f"Delete not implemented for {self.kind}.")
         return False
 
     # legacy interface
@@ -102,45 +102,7 @@ class AwsResource(BaseResource, ABC):
 
     # legacy interface
     def delete(self, graph: Graph) -> bool:
-        return self.delete_resource(get_client(current_config(), self))
-
-    def to_json(self) -> Json:
-        return to_js(
-            self,
-            strip_attr=(
-                "mapping",
-                "phantom",
-                "reference_kinds",
-                "parent_resource",
-                "usage_percentage",
-                "dname",
-                "kdname",
-                "rtdname",
-                "changes",
-                "event_log",
-                "str_event_log",
-                "chksum",
-                "age",
-                "last_access",
-                "last_update",
-                "clean",
-                "cleaned",
-                "protected",
-                "_graph",
-                "graph",
-                "max_graph_depth",
-                "resource_type",
-                "age",
-                "last_access",
-                "last_update",
-                "clean",
-                "cleaned",
-                "protected",
-                "uuid",
-                "kind",
-                "api_spec",
-            ),
-        )
+        return self.delete_resource(get_client(current_config(), self), graph)
 
     def set_arn(
         self,
@@ -166,10 +128,6 @@ class AwsResource(BaseResource, ABC):
             return arn.rsplit("/")[-1]
         return arn.rsplit(":")[-1]
 
-    @classmethod
-    def from_json(cls: Type[AwsResourceType], json: Json) -> AwsResourceType:
-        return from_js(json, cls)
-
     @classmethod
     def from_api(cls: Type[AwsResourceType], json: Json) -> AwsResourceType:
         mapped = bend(cls.mapping, json)
