@@ -3,7 +3,7 @@ from test.resources import round_trip_for
 
 
 def test_efs_filesystem() -> None:
-    first, builder = round_trip_for(AwsEfsFileSystem, "volume_iops", "volume_throughput")
+    first, builder = round_trip_for(AwsEfsFileSystem, "share_iops")
     assert len(builder.resources_of(AwsEfsMountTarget)) == 2
 
 
